@@ -58,18 +58,15 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
 #include <string.h>
 
 #include "des-compat.h"
-
-#define C_Block des_cblock
-#define Key_schedule des_key_schedule
+#include "testutils.h"
 
 /* tisk tisk - the test keys don't all have odd parity :-( */
 /* test data */
 #define NUM_TESTS 34
-static unsigned char key_data[NUM_TESTS][8]={
+static const_des_cblock key_data[NUM_TESTS] = {
 	{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
 	{0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF},
 	{0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
@@ -212,11 +209,11 @@ static unsigned char cipher_ecb2[NUM_TESTS-1][8]={
 	{0x43,0x34,0xCF,0xDA,0x22,0xC4,0x86,0xC8},
 	{0x08,0xD7,0xB4,0xFB,0x62,0x9D,0x08,0x85}};
 
-static unsigned char cbc_key [8]={0x01,0x23,0x45,0x67,0x89,0xab,0xcd,0xef};
-static unsigned char cbc2_key[8]={0xf0,0xe1,0xd2,0xc3,0xb4,0xa5,0x96,0x87};
-static unsigned char cbc3_key[8]={0xfe,0xdc,0xba,0x98,0x76,0x54,0x32,0x10};
-static unsigned char cbc_iv  [8]={0xfe,0xdc,0xba,0x98,0x76,0x54,0x32,0x10};
-static char cbc_data[32]="7654321 Now is the time for ";
+static const_des_cblock cbc_key = {0x01,0x23,0x45,0x67,0x89,0xab,0xcd,0xef};
+static const_des_cblock cbc2_key = {0xf0,0xe1,0xd2,0xc3,0xb4,0xa5,0x96,0x87};
+static const_des_cblock cbc3_key = {0xfe,0xdc,0xba,0x98,0x76,0x54,0x32,0x10};
+static const_des_cblock cbc_iv = {0xfe,0xdc,0xba,0x98,0x76,0x54,0x32,0x10};
+static const_des_cblock cbc_data[4] ={ "7654321 ", "Now is t", "he time ", "for " };
 
 static unsigned char cbc_ok[32]={
 	0xcc,0xd1,0x73,0xff,0xab,0x20,0x39,0xf4,
@@ -289,10 +286,12 @@ DES_LONG cbc_cksum_ret=0xB462FEF7L;
 unsigned char cbc_cksum_data[8]={0x1D,0x26,0x93,0x97,0xf7,0xfe,0x62,0xb4};
 
 #ifndef NOPROTO
-static char *pt(unsigned char *p);
+static char *pt(const unsigned char *p);
+#if 0
 static int cfb_test(int bits, unsigned char *cfb_cipher);
 static int cfb64_test(unsigned char *cfb_cipher);
 static int ede_cfb64_test(unsigned char *cfb_cipher);
+#endif
 #else
 static char *pt();
 static int cfb_test();
@@ -300,23 +299,26 @@ static int cfb64_test();
 static int ede_cfb64_test();
 #endif
 
-int main(int argc, char **argv)
+int
+test_main(void)
 	{
 	int i,j,err=0;
-	des_cblock in,out,outin,iv3;
+	des_cblock in, out, outin, iv3;
 	des_key_schedule ks,ks2,ks3;
-	unsigned char cbc_in[40];
-	unsigned char cbc_out[40];
+	des_cblock cbc_in[5];
+	des_cblock cbc_out[5];
 	DES_LONG cs;
-	unsigned char qret[4][4],cret[8];
+	unsigned char cret[8];
+#if 0
+	unsigned char qret[4][4];
 	DES_LONG lqret[4];
 	int num;
 	char *str;
-
-	printf("Doing ecb\n");
+#endif
+	if (verbose) printf("Doing ecb\n");
 	for (i=0; i<NUM_TESTS; i++)
 		{
-		if ((j=des_key_sched((C_Block *)(key_data[i]),ks)) != 0)
+		if ((j=des_key_sched(&key_data[i], ks)) != 0)
 			{
 			printf("Key error %2d:%d\n",i+1,j);
 			err=1;
@@ -324,8 +326,8 @@ int main(int argc, char **argv)
 		memcpy(in,plain_data[i],8);
 		memset(out,0,8);
 		memset(outin,0,8);
-		des_ecb_encrypt((C_Block *)in,(C_Block *)out,ks,DES_ENCRYPT);
-		des_ecb_encrypt((C_Block *)out,(C_Block *)outin,ks,DES_DECRYPT);
+		des_ecb_encrypt(&in, &out, ks, DES_ENCRYPT);
+		des_ecb_encrypt(&out, &outin, ks, DES_DECRYPT);
 
 		if (memcmp(out,cipher_data[i],8) != 0)
 			{
@@ -343,20 +345,20 @@ int main(int argc, char **argv)
 		}
 
 #ifndef LIBDES_LIT
-	printf("Doing ede ecb\n");
+	if (verbose) printf("Doing ede ecb\n");
 	for (i=0; i<(NUM_TESTS-1); i++)
 		{
-		if ((j=des_key_sched((C_Block *)(key_data[i]),ks)) != 0)
+		if ((j=des_key_sched(&key_data[i], ks)) != 0)
 			{
 			err=1;
 			printf("Key error %2d:%d\n",i+1,j);
 			}
-		if ((j=des_key_sched((C_Block *)(key_data[i+1]),ks2)) != 0)
+		if ((j=des_key_sched(&key_data[i+1],ks2)) != 0)
 			{
 			printf("Key error %2d:%d\n",i+2,j);
 			err=1;
 			}
-		if ((j=des_key_sched((C_Block *)(key_data[i+2]),ks3)) != 0)
+		if ((j=des_key_sched(&key_data[i+2],ks3)) != 0)
 			{
 			printf("Key error %2d:%d\n",i+3,j);
 			err=1;
@@ -364,9 +366,9 @@ int main(int argc, char **argv)
 		memcpy(in,plain_data[i],8);
 		memset(out,0,8);
 		memset(outin,0,8);
-		des_ecb2_encrypt((C_Block *)in,(C_Block *)out,ks,ks2,
+		des_ecb2_encrypt(&in, &out, ks, ks2,
 			DES_ENCRYPT);
-		des_ecb2_encrypt((C_Block *)out,(C_Block *)outin,ks,ks2,
+		des_ecb2_encrypt(&out, &outin, ks, ks2,
 			DES_DECRYPT);
 
 		if (memcmp(out,cipher_ecb2[i],8) != 0)
@@ -385,8 +387,8 @@ int main(int argc, char **argv)
 		}
 #endif
 
-	printf("Doing cbc\n");
-	if ((j=des_key_sched((C_Block *)cbc_key,ks)) != 0)
+	if (verbose) printf("Doing cbc\n");
+	if ((j=des_key_sched(&cbc_key, ks)) != 0)
 		{
 		printf("Key error %d\n",j);
 		err=1;
@@ -394,16 +396,16 @@ int main(int argc, char **argv)
 	memset(cbc_out,0,sizeof(cbc_data));
 	memset(cbc_in,0,sizeof(cbc_data));
 	memcpy(iv3,cbc_iv,sizeof(cbc_iv));
-	des_ncbc_encrypt((C_Block *)cbc_data,(C_Block *)cbc_out,
-		sizeof(cbc_data),ks,
-		(C_Block *)iv3,DES_ENCRYPT);
+	des_ncbc_encrypt(cbc_data, cbc_out,
+		sizeof(cbc_data), ks,
+		&iv3, DES_ENCRYPT);
 	if (memcmp(cbc_out,cbc_ok,32) != 0)
 		printf("cbc_encrypt encrypt error\n");
 
 	memcpy(iv3,cbc_iv,sizeof(cbc_iv));
-	des_ncbc_encrypt((C_Block *)cbc_out,(C_Block *)cbc_in,
+	des_ncbc_encrypt(cbc_out, cbc_in,
 		sizeof(cbc_data),ks,
-		(C_Block *)iv3,DES_DECRYPT);
+		&iv3,DES_DECRYPT);
 	if (memcmp(cbc_in,cbc_data,sizeof(cbc_data)) != 0)
 		{
 		printf("cbc_encrypt decrypt error\n");
@@ -412,7 +414,7 @@ int main(int argc, char **argv)
 
 #ifndef LIBDES_LIT
 #if 0
-	printf("Doing desx cbc\n");
+	if (verbose) printf("Doing desx cbc\n");
 	if ((j=des_key_sched((C_Block *)cbc_key,ks)) != 0)
 		{
 		printf("Key error %d\n",j);
@@ -442,18 +444,18 @@ int main(int argc, char **argv)
 #endif
 #endif /* LIBDES_LIT */
 
-	printf("Doing ede cbc\n");
-	if ((j=des_key_sched((C_Block *)cbc_key,ks)) != 0)
+	if (verbose) printf("Doing ede cbc\n");
+	if ((j=des_key_sched(&cbc_key,ks)) != 0)
 		{
 		printf("Key error %d\n",j);
 		err=1;
 		}
-	if ((j=des_key_sched((C_Block *)cbc2_key,ks2)) != 0)
+	if ((j=des_key_sched(&cbc2_key,ks2)) != 0)
 		{
 		printf("Key error %d\n",j);
 		err=1;
 		}
-	if ((j=des_key_sched((C_Block *)cbc3_key,ks3)) != 0)
+	if ((j=des_key_sched(&cbc3_key,ks3)) != 0)
 		{
 		printf("Key error %d\n",j);
 		err=1;
@@ -464,11 +466,11 @@ int main(int argc, char **argv)
 	/* i=((i+7)/8)*8; */
 	memcpy(iv3,cbc_iv,sizeof(cbc_iv));
 
-	des_ede3_cbc_encrypt((C_Block *)cbc_data,(C_Block *)cbc_out,
-		16L,ks,ks2,ks3,(C_Block *)iv3,DES_ENCRYPT);
-	des_ede3_cbc_encrypt((C_Block *)&(cbc_data[16]),
-		(C_Block *)&(cbc_out[16]),
-		(long)i-16,ks,ks2,ks3,(C_Block *)iv3,DES_ENCRYPT);
+	des_ede3_cbc_encrypt( cbc_data, cbc_out,
+		16L, ks, ks2, ks3, &iv3, DES_ENCRYPT);
+	des_ede3_cbc_encrypt( &cbc_data[2],
+		&cbc_out[2],
+		(long)i-16, ks, ks2, ks3, &iv3, DES_ENCRYPT);
 	if (memcmp(cbc_out,cbc3_ok, sizeof(cbc_data)) != 0)
 		{
 		printf("des_ede3_cbc_encrypt encrypt error\n");
@@ -476,8 +478,8 @@ int main(int argc, char **argv)
 		}
 
 	memcpy(iv3,cbc_iv,sizeof(cbc_iv));
-	des_ede3_cbc_encrypt((C_Block *)cbc_out,(C_Block *)cbc_in,
-		(long)i,ks,ks2,ks3,(C_Block *)iv3,DES_DECRYPT);
+	des_ede3_cbc_encrypt(cbc_out, cbc_in,
+		(long)i, ks, ks2, ks3, &iv3, DES_DECRYPT);
 	if (memcmp(cbc_in,cbc_data,sizeof(cbc_data)) != 0)
 		{
 		printf("des_ede3_cbc_encrypt decrypt error\n");
@@ -633,10 +635,10 @@ plain[8+4], plain[8+5], plain[8+6], plain[8+7]);
 		}
 #endif
         
-	printf("Doing cbc_cksum\n");
-	des_key_sched((C_Block *)cbc_key,ks);
-	cs=des_cbc_cksum((C_Block *)cbc_data,(C_Block *)cret,
-		sizeof(cbc_data),ks,(C_Block *)cbc_iv);
+	if (verbose) printf("Doing cbc_cksum\n");
+	des_key_sched(&cbc_key,ks);
+	cs=des_cbc_cksum(cbc_data[0], &cret,
+		sizeof(cbc_data), ks, &cbc_iv);
 	if (cs != cbc_cksum_ret)
 		{
 		printf("bad return value (%08lX), should be %08lX\n",
@@ -705,25 +707,25 @@ plain[8+4], plain[8+5], plain[8+6], plain[8+7]);
 		}
 #endif
 #endif /* LIBDES_LIT */
-
+#if 0
 	printf("input word alignment test");
 	for (i=0; i<4; i++)
 		{
 		printf(" %d",i);
-		des_ncbc_encrypt((C_Block *)&(cbc_out[i]),(C_Block *)cbc_in,
-			sizeof(cbc_data),ks,(C_Block *)cbc_iv,
+		des_ncbc_encrypt( (des_cblock *) &(cbc_out[i]), (des_cblock *) cbc_in,
+			sizeof(cbc_data), ks, &cbc_iv,
 			DES_ENCRYPT);
 		}
 	printf("\noutput word alignment test");
 	for (i=0; i<4; i++)
 		{
 		printf(" %d",i);
-		des_ncbc_encrypt((C_Block *)cbc_out,(C_Block *)&(cbc_in[i]),
-			sizeof(cbc_data),ks,(C_Block *)cbc_iv,
+		des_ncbc_encrypt( (des_cblock *) cbc_out, (des_cblock *) &(cbc_in[i]),
+			sizeof(cbc_data), ks, &cbc_iv,
 			DES_ENCRYPT);
 		}
 	printf("\n");
-#if 0
+
 	printf("fast crypt test ");
 	str=crypt("testing","ef");
 	if (strcmp("efGnQx2725bI2",str) != 0)
@@ -744,7 +746,7 @@ plain[8+4], plain[8+5], plain[8+6], plain[8+7]);
 	}
 
 static char *pt(p)
-unsigned char *p;
+const unsigned char *p;
 	{
 	static char bufs[10][20];
 	static int bnum=0;
